'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.getToleranceFromColor = getToleranceFromColor;
exports.getColorFromTolerance = getColorFromTolerance;
exports.getColorFromValue = getColorFromValue;
exports.getValueFromColor = getValueFromColor;
exports.getSymbolFromExp = getSymbolFromExp;
exports.getPowerFromSymbol = getPowerFromSymbol;

var _utils = require('./utils');

var colorToValueMap = {
    'black': 0,
    'brown': 1,
    'red': 2,
    'orange': 3,
    'yellow': 4,
    'green': 5,
    'blue': 6,
    'violet': 7,
    'grey': 8,
    'white': 9,
    'gold': -1,
    'silver': -2
};

var colorToTolerance = {
    'brown': 1,
    'red': 2,
    'yellow': 5,
    'green': 0.5,
    'blue': 0.25,
    'violet': 0.1,
    'grey': 0.05,
    'gold': 5,
    'silver': 10,
    'none': 20
};
var expToSymbolMap = {
    6: 'm',
    3: 'k',
    0: ''
};
var symbolPowerToMap = {
    'm': Math.pow(10, 6),
    'k': Math.pow(10, 3),
    'r': Math.pow(10, 0)
};
var valueToColourMap = (0, _utils.makeReverseMap)(colorToValueMap);
var toleranceToColourMap = (0, _utils.makeReverseMap)(colorToTolerance);

function getToleranceFromColor(color) {
    return colorToTolerance[color];
}

function getColorFromTolerance(tolerance) {
    return toleranceToColourMap[tolerance];
}

function getColorFromValue(value) {
    return valueToColourMap[value];
}

function getValueFromColor(color) {
    var value = colorToValueMap[color];
    if (typeof value === 'undefined') {
        throw new Error('Invalid colour ' + color);
    }
    return value;
}

function getSymbolFromExp(exp) {
    return expToSymbolMap[exp];
}

function getPowerFromSymbol(symbol) {
    var value = symbolPowerToMap[symbol.toLowerCase()];
    if (typeof value === 'undefined') {
        throw new Error('Invalid symbol ' + symbol);
    }
    return value;
}