'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.notationToBands = exports.bandsToNotation = undefined;

var _resistorNotation = require('./resistor-notation');

var _utils = require('./utils');

var _lookups = require('./lookups');

var bandsToNotation = exports.bandsToNotation = function bandsToNotation() {
    var bands = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

    if (!Array.isArray(bands)) {
        throw new TypeError('Expected an array');
    } else if (bands.length < 4 || bands.length > 5) {
        throw new Error('A resistor should have 4 or 5 bands');
    }
    var clone = bands.slice(0);
    var tolerance = (0, _lookups.getToleranceFromColor)(clone.pop());
    var exp = (0, _lookups.getValueFromColor)(clone.pop());

    var value = clone.reverse().reduce(function (sum, current, currentIndex) {
        return sum + (0, _lookups.getValueFromColor)(current) * Math.pow(10, currentIndex);
    }, 0) * Math.pow(10, exp);

    return [(0, _resistorNotation.valueToNotation)(value), tolerance];
};

var notationToBands = exports.notationToBands = function notationToBands(data) {
    var bands = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 5;


    if (!Array.isArray(data)) {
        throw new TypeError('Expected an array');
    }

    var value = (0, _resistorNotation.notationToValue)(data[0]);
    var tolerance = data[1] || 1;
    var digits = (value * 1000).toString().split('').slice(0, bands - 2);

    var exp = (0, _utils.getExponentialFor10)(value / digits.join(''));

    return digits.map(function (item) {
        return (0, _lookups.getColorFromValue)(item);
    }).concat([(0, _lookups.getColorFromValue)(exp), (0, _lookups.getColorFromTolerance)(tolerance)]);
};