'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.valueToNotation = exports.notationToValue = undefined;

var _utils = require('./utils');

var _lookups = require('./lookups');

var validRegex = /\d+\.?\d*\D?\d*/;
var matchRegex = /[\D]/i;

var notationToValue = exports.notationToValue = function notationToValue() {
    var notation = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';


    if (!validRegex.test(notation)) {
        throw new Error('Invalid string');
    }
    var value = notation;
    if (typeof notation === 'string' && notation.trim()) {
        var match = matchRegex.exec(notation) || ['r'];
        var symbol = match[0];
        var multiplier = (0, _lookups.getPowerFromSymbol)(symbol);
        value = notation.split(symbol).join('.') * multiplier;
    }
    return parseInt(value, 10);
};

var valueToNotation = exports.valueToNotation = function valueToNotation(value) {

    if (value === '') {
        throw new Error('Invalid value');
    }

    if (isNaN(value)) {
        throw new Error('Invalid value');
    }

    var exp = (0, _utils.roundToStandard)((0, _utils.getExponentialFor10)(value));
    var multiplier = Math.pow(10, exp);
    var res = (value / multiplier).toString();
    var notation = void 0;
    if (res.indexOf('.') == '-1') {
        notation = res + (0, _lookups.getSymbolFromExp)(exp);
    } else {
        notation = res.split('.').join((0, _lookups.getSymbolFromExp)(exp));
    }
    return notation;
};